@@ -70,10 +70,22 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #  endif /* ?MSDOS */
 #endif /* ?VMS */
 
-#if (defined(UNIX) || defined(WCD_WINZSH) || defined(WCD_DOSBASH) || defined(WCD_OS2BASH))
-# define LIST_SEPARATOR ":"
-#else
+#if defined(UNIX) || defined(WIN32) || defined(WCD_DOSBASH) || defined(OS2)
+/* A go-script is required */
+#define WCD_SHELL
+#endif
+/* OS/2 GCC environment defines UNIX. Don't define WCD_UNIXSHELL when we build
+ * for standard OS/2 cmd.exe shell */
+#if ((defined(UNIX) && !defined(OS2)) || defined(WCD_WINZSH) || defined(WCD_DOSBASH) || defined(WCD_OS2BASH))
+#define WCD_UNIXSHELL
+#endif
+
+/* Unix shells DJGPP-bash and WinZsh use Windows style paths, e.g. "c:/Program Files".
+ * So in these shells we have to use a semicolon ';' as list separator. */
+#ifdef MSDOS
 # define LIST_SEPARATOR ";"
+#else
+# define LIST_SEPARATOR ":"
 #endif
 
 #if defined(MSDOS) || defined(VMS)
@@ -82,8 +94,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #  define OP_DIR "."
 #endif /* ?MSDOS|VMS */
 
-#define VERSION      "5.1.2"
-#define VERSION_DATE "2010-05-23"
+#define VERSION      "5.1.3"
+#define VERSION_DATE "2010-08-29"
 
 
 /* Function prototypes */
